.. Ditalini documentation master file

Welcome to Ditalini's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

:ref:`genindex`

Docs
====

.. doxygenclass:: ditalini::Simulation
   :members: